@@ -1,3 +1,4 @@
+from typing import Union
 from pydantic import BaseModel
 
 class Environment(BaseModel):
@@ -7,6 +8,7 @@ class Environment(BaseModel):
     PUB_SUB: str
     # Whether we should wait for DAPR server to be active before loading
     NO_WAIT: bool = False
+    LOG_LEVEL: Union[str, int] = "DEBUG"
     # Postgres connection details
     POSTGRES_URL: str
     POSTGRES_SCHEMA: str
